# Summary

- [Getting Started](get_started.md)
- [Python Modules](module.md)
- [Python Functions](function.md)
- [Python Classes](class.md)
- [Type Conversions](conversions.md)
- [Python Exceptions](exception.md)
- [Calling Python from Rust](python_from_rust.md)
- [GIL, mutability and object types](types.md)
- [Parallelism](parallelism.md)
- [Debugging](debugging.md)
- [Advanced Topics](advanced.md)
- [Building and Distribution](building_and_distribution.md)
- [PyPy support](pypy.md)
- [Appendix A: PyO3 and rust-cpython](rust_cpython.md)
- [Appendix B: Migration Guide](migration.md)
